import { Configuration, App } from '@midwayjs/decorator';
import * as koa from '@midwayjs/koa';
import * as validate from '@midwayjs/validate';
import * as info from '@midwayjs/info';
import { join } from 'path';
import * as FreeFrame from 'free-midway-component';
import * as swagger from '@midwayjs/swagger';
import * as jwt from '@midwayjs/jwt';
import * as axios from '@midwayjs/axios';
import { SetUserMiddleware } from './middleware/setUser.middleware';
import { SelfDataMiddleware } from './middleware/selfData.middeware';
import { Inject, MidwayDecoratorService } from '@midwayjs/core';
import { SELFDATA_KEY, selfDataInit } from './decorator/selfData.decorator';
import { ADDACTTIME_KEY, AddActTimeInit } from './decorator/addActTime.decorator';
@Configuration({
  imports: [
    FreeFrame,
    validate,
    jwt,
    axios,
    swagger,
    validate,
    {
      component: info,
      enabledEnvironment: ['local'],
    },
  ],
  importConfigs: [join(__dirname, './config')],
})
export class ContainerLifeCycle {
  @App()
  app: koa.Application;
  @Inject()
  decoratorService: MidwayDecoratorService;

  async onReady() {
    this.app.useMiddleware([SetUserMiddleware, SelfDataMiddleware]);
    this.decoratorService.registerMethodHandler(SELFDATA_KEY, selfDataInit);
    this.decoratorService.registerMethodHandler(ADDACTTIME_KEY, options => AddActTimeInit(options));
  }
}
