import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { AwardService } from '../../service/achievements/award.service';
import { CDTO_award, CVO_award, FVO_award, QDTO_award, QVO_award, UDTO_award, UVAO_award } from '../../interface/achievements/award.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { SelfData } from '../../decorator/selfData.decorator';
import { AddActTime } from '../../decorator/addActTime.decorator';
@ApiTags(['获奖情况'])
@Controller('/award')
export class AwardController extends BaseController {
  @Inject()
  service: AwardService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_award })
  @AddActTime()
  async create(@Body() data: CDTO_award) {
    const dbData = await this.service.create(data);
    const result = new CVO_award(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_award })
  @SelfData()
  async query(@Query() filter: QDTO_award, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_award(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_award })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_award(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_award })
  async update(@Param('id') id: string, @Body() body: UDTO_award) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
