import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { EquipmentService } from '../../service/achievements/equipment.service';
import { CDTO_equipment, CVO_equipment, FVO_equipment, QDTO_equipment, QVO_equipment, UDTO_equipment, UVAO_equipment } from '../../interface/achievements/equipment.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { SelfData } from '../../decorator/selfData.decorator';
import { AddActTime } from '../../decorator/addActTime.decorator';
@ApiTags(['设备及场地'])
@Controller('/equipment')
export class EquipmentController extends BaseController {
  @Inject()
  service: EquipmentService;

  @Get('/statistics')
  async statistics(@Query('lab_id') lab_id: string) {
    const result = await this.service.statistics(lab_id);
    return result;
  }

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_equipment })
  @AddActTime()
  async create(@Body() data: CDTO_equipment) {
    const dbData = await this.service.create(data);
    const result = new CVO_equipment(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_equipment })
  @SelfData()
  async query(@Query() filter: QDTO_equipment, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_equipment(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_equipment })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_equipment(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_equipment })
  async update(@Param('id') id: string, @Body() body: UDTO_equipment) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
