import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { FixInputService } from '../../service/achievements/fixInput.service';
import { CDTO_fixInput, CVO_fixInput, FVO_fixInput, QDTO_fixInput, QVO_fixInput, UDTO_fixInput, UVAO_fixInput } from '../../interface/achievements/fixInput.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { SelfData } from '../../decorator/selfData.decorator';
import { AddActTime } from '../../decorator/addActTime.decorator';
@ApiTags(['固定投入'])
@Controller('/fixInput')
export class FixInputController extends BaseController {
  @Inject()
  service: FixInputService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_fixInput })
  @AddActTime()
  async create(@Body() data: CDTO_fixInput) {
    const dbData = await this.service.create(data);
    const result = new CVO_fixInput(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_fixInput })
  @SelfData()
  async query(@Query() filter: QDTO_fixInput, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_fixInput(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_fixInput })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_fixInput(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_fixInput })
  async update(@Param('id') id: string, @Body() body: UDTO_fixInput) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
