import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { OtherAwardService } from '../../service/achievements/otherAward.service';
import { CDTO_otherAward, CVO_otherAward, FVO_otherAward, QDTO_otherAward, QVO_otherAward, UDTO_otherAward, UVAO_otherAward } from '../../interface/achievements/otherAward.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { SelfData } from '../../decorator/selfData.decorator';
import { AddActTime } from '../../decorator/addActTime.decorator';
@ApiTags(['其他代表性成果'])
@Controller('/otherAward')
export class OtherAwardController extends BaseController {
  @Inject()
  service: OtherAwardService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_otherAward })
  @AddActTime()
  async create(@Body() data: CDTO_otherAward) {
    const dbData = await this.service.create(data);
    const result = new CVO_otherAward(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_otherAward })
  @SelfData()
  async query(@Query() filter: QDTO_otherAward, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_otherAward(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_otherAward })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_otherAward(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_otherAward })
  async update(@Param('id') id: string, @Body() body: UDTO_otherAward) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
