import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { PaperService } from '../../service/achievements/paper.service';
import { CDTO_paper, CVO_paper, FVO_paper, QDTO_paper, QVO_paper, UDTO_paper, UVAO_paper } from '../../interface/achievements/paper.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { SelfData } from '../../decorator/selfData.decorator';
import { AddActTime } from '../../decorator/addActTime.decorator';
@ApiTags(['代表性论文'])
@Controller('/paper')
export class PaperController extends BaseController {
  @Inject()
  service: PaperService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_paper })
  @AddActTime()
  async create(@Body() data: CDTO_paper) {
    const dbData = await this.service.create(data);
    const result = new CVO_paper(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_paper })
  @SelfData()
  async query(@Query() filter: QDTO_paper, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_paper(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_paper })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_paper(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_paper })
  async update(@Param('id') id: string, @Body() body: UDTO_paper) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
