import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { TechnicalserviceService } from '../../service/achievements/technicalservice.service';
import {
  CDTO_technicalservice,
  CVO_technicalservice,
  FVO_technicalservice,
  QDTO_technicalservice,
  QVO_technicalservice,
  UDTO_technicalservice,
  UVAO_technicalservice,
} from '../../interface/achievements/technicalservice.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { SelfData } from '../../decorator/selfData.decorator';
import { AddActTime } from '../../decorator/addActTime.decorator';
@ApiTags(['开放服务'])
@Controller('/technicalservice')
export class TechnicalserviceController extends BaseController {
  @Inject()
  service: TechnicalserviceService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_technicalservice })
  @AddActTime()
  async create(@Body() data: CDTO_technicalservice) {
    const dbData = await this.service.create(data);
    const result = new CVO_technicalservice(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_technicalservice })
  @SelfData()
  async query(@Query() filter: QDTO_technicalservice, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_technicalservice(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_technicalservice })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_technicalservice(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_technicalservice })
  async update(@Param('id') id: string, @Body() body: UDTO_technicalservice) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
