import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ActivitysService } from '../service/activitys.service';
import { CDTO_activitys, CVO_activitys, FVO_activitys, QDTO_activitys, QVO_activitys, UDTO_activitys, UVAO_activitys } from '../interface/activitys.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['活动时间'])
@Controller('/activitys')
export class ActivitysController extends BaseController {
  @Inject()
  service: ActivitysService;

  @Get('/isInAct')
  async isInAct() {
    const result = await this.service.isInAct();
    return result;
  }

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_activitys })
  async create(@Body() data: CDTO_activitys) {
    const dbData = await this.service.create(data);
    const result = new CVO_activitys(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_activitys })
  async query(@Query() filter: QDTO_activitys, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_activitys(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_activitys })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_activitys(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_activitys })
  async update(@Param('id') id: string, @Body() body: UDTO_activitys) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
