import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { BasicService } from '../service/basic.service';
import { CDTO_basic, CVO_basic, FVO_basic, QDTO_basic, QVO_basic, UDTO_basic, UVAO_basic } from '../interface/basic.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { Context } from '@midwayjs/koa';
@ApiTags(['实验室基础信息'])
@Controller('/basic')
export class BasicController extends BaseController {
  @Inject()
  service: BasicService;

  @Inject()
  ctx: Context;

  @Get('/percent')
  async percent(@Query() query: QDTO_basic, @Query('skip') skip: number, @Query('limit') limit: number) {
    const result = await this.service.percent(query, { skip, limit });
    return result;
  }

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_basic })
  async create(@Body() data: CDTO_basic) {
    const dbData = await this.service.create(data);
    await this.service.afterCreate(dbData);
    const result = new CVO_basic(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_basic })
  async query(@Query() filter: QDTO_basic, @Query('skip') skip: number, @Query('limit') limit: number) {
    const user = this.ctx.user;
    if (user && user.role_type === '3') filter.unit = user._id;
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_basic(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_basic })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_basic(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_basic })
  async update(@Param('id') id: string, @Body() body: UDTO_basic) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
