import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { BuildService } from '../service/build.service';
import { CDTO_build, CVO_build, FVO_build, QDTO_build, QVO_build, UDTO_build, UVAO_build } from '../interface/build.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { SelfData } from '../decorator/selfData.decorator';
import { AddActTime } from '../decorator/addActTime.decorator';
@ApiTags(['平台建设'])
@Controller('/build')
export class BuildController extends BaseController {
  @Inject()
  service: BuildService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_build })
  @AddActTime()
  async create(@Body() data: CDTO_build) {
    const dbData = await this.service.create(data);
    const result = new CVO_build(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_build })
  @SelfData()
  async query(@Query() filter: QDTO_build, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_build(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_build })
  async fetch(@Param('id') id: string) {
    const data = await this.service.buildfetch(id);
    const result = new FVO_build(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_build })
  async update(@Param('id') id: string, @Body() body: UDTO_build) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
