import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ScienceactivitiesService } from '../../service/communication/scienceactivities.service';
import {
  CDTO_scienceactivities,
  CVO_scienceactivities,
  FVO_scienceactivities,
  QDTO_scienceactivities,
  QVO_scienceactivities,
  UDTO_scienceactivities,
  UVAO_scienceactivities,
} from '../../interface/communication/scienceactivities.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { SelfData } from '../../decorator/selfData.decorator';
import { AddActTime } from '../../decorator/addActTime.decorator';
@ApiTags(['科普活动'])
@Controller('/scienceactivities')
export class ScienceactivitiesController extends BaseController {
  @Inject()
  service: ScienceactivitiesService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_scienceactivities })
  @AddActTime()
  async create(@Body() data: CDTO_scienceactivities) {
    const dbData = await this.service.create(data);
    const result = new CVO_scienceactivities(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_scienceactivities })
  @SelfData()
  async query(@Query() filter: QDTO_scienceactivities, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_scienceactivities(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_scienceactivities })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_scienceactivities(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_scienceactivities })
  async update(@Param('id') id: string, @Body() body: UDTO_scienceactivities) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
