import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { SjactivityService } from '../../service/communication/sjactivity.service';
import { CDTO_sjactivity, CVO_sjactivity, FVO_sjactivity, QDTO_sjactivity, QVO_sjactivity, UDTO_sjactivity, UVAO_sjactivity } from '../../interface/communication/sjactivity.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { SelfData } from '../../decorator/selfData.decorator';
import { AddActTime } from '../../decorator/addActTime.decorator';
@ApiTags(['参与省部级以上政府组织的社会服务活动'])
@Controller('/sjactivity')
export class SjactivityController extends BaseController {
  @Inject()
  service: SjactivityService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_sjactivity })
  @AddActTime()
  async create(@Body() data: CDTO_sjactivity) {
    const dbData = await this.service.create(data);
    const result = new CVO_sjactivity(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_sjactivity })
  @SelfData()
  async query(@Query() filter: QDTO_sjactivity, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_sjactivity(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_sjactivity })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_sjactivity(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_sjactivity })
  async update(@Param('id') id: string, @Body() body: UDTO_sjactivity) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
