import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { DirectionService } from '../service/direction.service';
import { CDTO_direction, CVO_direction, FVO_direction, QDTO_direction, QVO_direction, UDTO_direction, UVAO_direction } from '../interface/direction.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { SelfData } from '../decorator/selfData.decorator';
import { AddActTime } from '../decorator/addActTime.decorator';
@ApiTags(['研究方向'])
@Controller('/direction')
export class DirectionController extends BaseController {
  @Inject()
  service: DirectionService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_direction })
  @AddActTime()
  async create(@Body() data: CDTO_direction) {
    const dbData = await this.service.create(data);
    const result = new CVO_direction(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_direction })
  @SelfData()
  async query(@Query() filter: QDTO_direction, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_direction(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_direction })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_direction(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_direction })
  async update(@Param('id') id: string, @Body() body: UDTO_direction) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
