import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { OutcomeService } from '../service/outcome.service';
import { CDTO_outcome, CVO_outcome, FVO_outcome, QDTO_outcome, QVO_outcome, UDTO_outcome, UVAO_outcome } from '../interface/outcome.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { SelfData } from '../decorator/selfData.decorator';
import { AddActTime } from '../decorator/addActTime.decorator';
@ApiTags(['重要成果'])
@Controller('/outcome')
export class OutcomeController extends BaseController {
  @Inject()
  service: OutcomeService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_outcome })
  @AddActTime()
  async create(@Body() data: CDTO_outcome) {
    const dbData = await this.service.create(data);
    const result = new CVO_outcome(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_outcome })
  @SelfData()
  async query(@Query() filter: QDTO_outcome, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_outcome(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_outcome })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_outcome(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_outcome })
  async update(@Param('id') id: string, @Body() body: UDTO_outcome) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
