import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { CommitteeService } from '../../service/person/committee.service';
import { CDTO_committee, CVO_committee, FVO_committee, QDTO_committee, QVO_committee, UDTO_committee, UVAO_committee } from '../../interface/person/committee.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { SelfData } from '../../decorator/selfData.decorator';
import { AddActTime } from '../../decorator/addActTime.decorator';
@ApiTags(['学术委员会'])
@Controller('/committee')
export class CommitteeController extends BaseController {
  @Inject()
  service: CommitteeService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_committee })
  @AddActTime()
  async create(@Body() data: CDTO_committee) {
    const dbData = await this.service.create(data);
    const result = new CVO_committee(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_committee })
  @SelfData()
  async query(@Query() filter: QDTO_committee, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_committee(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_committee })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_committee(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_committee })
  async update(@Param('id') id: string, @Body() body: UDTO_committee) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
