import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { FixedpersonnelService } from '../../service/person/fixedpersonnel.service';
import {
  CDTO_fixedpersonnel,
  CVO_fixedpersonnel,
  FVO_fixedpersonnel,
  QDTO_fixedpersonnel,
  QVO_fixedpersonnel,
  UDTO_fixedpersonnel,
  UVAO_fixedpersonnel,
} from '../../interface/person/fixedpersonnel.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { SelfData } from '../../decorator/selfData.decorator';
import { AddActTime } from '../../decorator/addActTime.decorator';
@ApiTags(['固定人员'])
@Controller('/fixedpersonnel')
export class FixedpersonnelController extends BaseController {
  @Inject()
  service: FixedpersonnelService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_fixedpersonnel })
  @AddActTime()
  async create(@Body() data: CDTO_fixedpersonnel) {
    const dbData = await this.service.create(data);
    const result = new CVO_fixedpersonnel(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_fixedpersonnel })
  @SelfData()
  async query(@Query() filter: QDTO_fixedpersonnel, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_fixedpersonnel(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_fixedpersonnel })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_fixedpersonnel(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_fixedpersonnel })
  async update(@Param('id') id: string, @Body() body: UDTO_fixedpersonnel) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
