import { FlowpersonnelService } from '../../service/person/flowpersonnel.service';
import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import {
  CDTO_flowpersonnel,
  CVO_flowpersonnel,
  FVO_flowpersonnel,
  QDTO_flowpersonnel,
  QVO_flowpersonnel,
  UDTO_flowpersonnel,
  UVAO_flowpersonnel,
} from '../../interface/person/flowpersonnel.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { SelfData } from '../../decorator/selfData.decorator';
import { AddActTime } from '../../decorator/addActTime.decorator';
@ApiTags(['流动人员'])
@Controller('/flowpersonnel')
export class FlowpersonnelController extends BaseController {
  @Inject()
  service: FlowpersonnelService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_flowpersonnel })
  @AddActTime()
  async create(@Body() data: CDTO_flowpersonnel) {
    const dbData = await this.service.create(data);
    const result = new CVO_flowpersonnel(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_flowpersonnel })
  @SelfData()
  async query(@Query() filter: QDTO_flowpersonnel, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_flowpersonnel(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_flowpersonnel })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_flowpersonnel(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_flowpersonnel })
  async update(@Param('id') id: string, @Body() body: UDTO_flowpersonnel) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
