import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { PolicyfileService } from '../service/policyfile.service';
import { CDTO_policyfile, CVO_policyfile, FVO_policyfile, QDTO_policyfile, QVO_policyfile, UDTO_policyfile, UVAO_policyfile } from '../interface/policyfile.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['政策文件'])
@Controller('/policyfile')
export class PolicyfileController extends BaseController {
  @Inject()
  service: PolicyfileService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_policyfile })
  async create(@Body() data: CDTO_policyfile) {
    const dbData = await this.service.create(data);
    const result = new CVO_policyfile(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_policyfile })
  async query(@Query() filter: QDTO_policyfile, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_policyfile(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_policyfile })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_policyfile(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_policyfile })
  async update(@Param('id') id: string, @Body() body: UDTO_policyfile) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
