import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ResourceService } from '../service/resource.service';
import { CDTO_resource, CVO_resource, FVO_resource, QDTO_resource, QVO_resource, UDTO_resource, UVAO_resource } from '../interface/resource.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['项目来源'])
@Controller('/resource')
export class ResourceController extends BaseController {
  @Inject()
  service: ResourceService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_resource })
  async create(@Body() data: CDTO_resource) {
    const dbData = await this.service.create(data);
    const result = new CVO_resource(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_resource })
  async query(@Query() filter: QDTO_resource, @Query('skip') skip: number, @Query('limit') limit: number) {
    const sort = { sort: 1 };
    if (filter.sort === -1) {
      sort.sort = 1;
      delete filter.sort;
    }
    const list = await this.service.query(filter, { skip, limit, sort });
    const data = [];
    for (const i of list) {
      const newData = new QVO_resource(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_resource })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_resource(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_resource })
  async update(@Param('id') id: string, @Body() body: UDTO_resource) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
