import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { DoctorService } from '../../service/team/doctor.service';
import { CDTO_doctor, CVO_doctor, FVO_doctor, QDTO_doctor, QVO_doctor, UDTO_doctor, UVAO_doctor } from '../../interface/team/doctor.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { SelfData } from '../../decorator/selfData.decorator';
import { AddActTime } from '../../decorator/addActTime.decorator';
@ApiTags(['博硕培养'])
@Controller('/doctor')
export class DoctorController extends BaseController {
  @Inject()
  service: DoctorService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_doctor })
  @AddActTime()
  async create(@Body() data: CDTO_doctor) {
    const dbData = await this.service.create(data);
    const result = new CVO_doctor(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_doctor })
  @SelfData()
  async query(@Query() filter: QDTO_doctor, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_doctor(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_doctor })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_doctor(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_doctor })
  async update(@Param('id') id: string, @Body() body: UDTO_doctor) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
