import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { PersonnelnameService } from '../../service/team/personnelname.service';
import { CDTO_personnelname, CVO_personnelname, FVO_personnelname, QDTO_personnelname, QVO_personnelname, UDTO_personnelname, UVAO_personnelname } from '../../interface/team/personnelname.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { SelfData } from '../../decorator/selfData.decorator';
import { AddActTime } from '../../decorator/addActTime.decorator';
@ApiTags(['省部级及以上人才称号'])
@Controller('/personnelname')
export class PersonnelnameController extends BaseController {
  @Inject()
  service: PersonnelnameService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_personnelname })
  @AddActTime()
  async create(@Body() data: CDTO_personnelname) {
    const dbData = await this.service.create(data);
    const result = new CVO_personnelname(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_personnelname })
  @SelfData()
  async query(@Query() filter: QDTO_personnelname, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_personnelname(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_personnelname })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_personnelname(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_personnelname })
  async update(@Param('id') id: string, @Body() body: UDTO_personnelname) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
