import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { TitleService } from '../../service/team/title.service';
import { CDTO_title, CVO_title, FVO_title, QDTO_title, QVO_title, UDTO_title, UVAO_title } from '../../interface/team/title.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { SelfData } from '../../decorator/selfData.decorator';
import { AddActTime } from '../../decorator/addActTime.decorator';
@ApiTags(['职称晋升'])
@Controller('/title')
export class TitleController extends BaseController {
  @Inject()
  service: TitleService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_title })
  @AddActTime()
  async create(@Body() data: CDTO_title) {
    const dbData = await this.service.create(data);
    const result = new CVO_title(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_title })
  @SelfData()
  async query(@Query() filter: QDTO_title, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_title(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_title })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_title(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_title })
  async update(@Param('id') id: string, @Body() body: UDTO_title) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
