import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { TecAwardService } from '../service/tecAward.service';
import { CDTO_tecAward, CVO_tecAward, FVO_tecAward, QDTO_tecAward, QVO_tecAward, UDTO_tecAward, UVAO_tecAward } from '../interface/tecAward.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['知识产权/标准表'])
@Controller('/tecAward')
export class TecAwardController extends BaseController {
  @Inject()
  service: TecAwardService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_tecAward })
  async create(@Body() data: CDTO_tecAward) {
    const dbData = await this.service.create(data);
    const result = new CVO_tecAward(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_tecAward })
  async query(@Query() filter: QDTO_tecAward, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_tecAward(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_tecAward })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_tecAward(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_tecAward })
  async update(@Param('id') id: string, @Body() body: UDTO_tecAward) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
