import { createCustomMethodDecorator, JoinPoint } from '@midwayjs/core';
import { JwtService } from '@midwayjs/jwt';
import get = require('lodash/get');

export const SELFDATA_KEY = 'decorator:selfData';
// meta元信息
export function SelfData(): MethodDecorator {
  return createCustomMethodDecorator(SELFDATA_KEY, {});
}

// 实现
export function selfDataInit(options) {
  return {
    around: async (joinPoint: JoinPoint) => {
      const token = joinPoint.target.ctx.request.header.token;
      const query = joinPoint.args[0];
      if (token) {
        const jwtService = new JwtService();
        const user = await jwtService.decode(token);
        const role_type = get(user, 'role_type');
        if (!role_type) return;
        else if (role_type === '2') {
          // 个人账号
          if (!get(query, 'lab_id')) {
            const lab_id = get(user, 'lab_id');
            if (lab_id) query.lab_id = lab_id;
          }
        } else if (role_type === '3') {
          // 依托单位账号
          if (!get(query, 'unit')) {
            const unit_id = get(user, '_id');
            if (unit_id) query.unit_id = unit_id;
          }
        }
      }
      const result = await joinPoint.proceed(...joinPoint.args);
      return result;
    },
  };
}
