import { modelOptions, prop } from '@typegoose/typegoose';
import { BaseModel } from 'free-midway-component';

// 申报单位
const unit = [
  {
    zh: '名称',
    key: 'name',
  },
  {
    zh: '通讯地址',
    key: 'address',
  },
  {
    zh: '联系人',
    key: 'contacts',
  },
  {
    zh: '联系电话',
    key: 'phone',
  },
  {
    zh: '单位类别',
    key: 'type',
    dict: 'declare_unit_type',
  },
  {
    zh: '是否为事业单位',
    key: 'is_career',
    dict: 'declare_unit_career',
  },
  {
    zh: '隶属',
    key: 'subjection',
    dict: 'declare_unit_subjection',
  },
];
// 平台负责人
const leading_cadre = [
  {
    zh: '姓名',
    key: 'name',
  },
  {
    zh: '性别',
    key: 'gender',
    dict: 'sys_user_sex',
  },
  {
    zh: '出生年月',
    key: 'birth',
  },
  {
    zh: '证件类别',
    key: 'cardtype',
    dict: 'leading_cadre_cardtype',
  },
  {
    zh: '证件号码',
    key: 'num',
  },

  {
    zh: '学历',
    key: 'education',
    dict: 'educationList',
  },
  {
    zh: '学位',
    key: 'degree',
    dict: 'degree',
  },
  {
    zh: '职称',
    key: 'title',
    dict: 'title',
  },
  {
    zh: '研究领域',
    key: 'field',
  },
  {
    zh: '工作单位',
    key: 'unit',
  },
  {
    zh: '电子邮箱',
    key: 'email',
  },
  {
    zh: '办公电话',
    key: 'work_phone',
  },
  {
    zh: '手机',
    key: 'phone',
  },
];
// 科研助理
const assistant = [
  {
    zh: '姓名',
    key: 'name',
  },
  {
    zh: '证件类别',
    key: 'cardtype',
    dict: 'leading_cadre_cardtype',
  },
  {
    zh: '证件号码',
    key: 'num',
  },
  {
    zh: '工作单位',
    key: 'unit',
  },
  {
    zh: '电子邮箱',
    key: 'email',
  },
  {
    zh: '办公电话',
    key: 'work_phone',
  },
  {
    zh: '手机',
    key: 'phone',
  },
];
// 财务助理
const finance = [
  {
    zh: '姓名',
    key: 'name',
  },
  {
    zh: '证件类别',
    key: 'cardtype',
    dict: 'leading_cadre_cardtype',
  },
  {
    zh: '证件号码',
    key: 'num',
  },
  {
    zh: '工作单位',
    key: 'unit',
  },
  {
    zh: '电子邮箱',
    key: 'email',
  },
  {
    zh: '办公电话',
    key: 'work_phone',
  },
  {
    zh: '手机',
    key: 'phone',
  },
];

@modelOptions({
  schemaOptions: { collection: 'basic' },
})
export class Basic extends BaseModel {
  @prop({ required: false, index: true, zh: '实验室类别', remark: '字典:laboratory_type', dict: 'laboratory_type' })
  type: string;
  @prop({ required: false, index: true, zh: '实验室名称' })
  name: string;
  @prop({ required: false, index: false, zh: '英文名称' })
  english_name: string;
  @prop({ required: false, index: false, zh: '所属学科' })
  subject: string;
  @prop({ required: false, index: false, zh: '所属专业' })
  major: string;
  @prop({ required: false, index: false, zh: '实验室面积' })
  lab_acreage: string;
  @prop({ required: false, index: false, zh: '批建时间' })
  build_time: string;
  @prop({ required: false, index: false, zh: '实验室地址' })
  lab_address: string;
  @prop({ required: false, index: false, zh: '依托单位id', remark: 'unit_name不需要了,现在所有的实验室都有依托单位' })
  unit: string;
  @prop({ required: false, index: false, zh: '依托单位名称' })
  unit_name: string;
  @prop({ required: false, index: false, zh: '实验室定位' })
  position: string;
  @prop({ required: false, index: false, zh: '实验室建设方案' })
  plan: Array<any>;
  @prop({ required: false, index: false, zh: '实验室主任' })
  chief_name: string;
  @prop({ required: false, index: false, zh: '实验室联系人' })
  lab_person: string;
  @prop({ required: false, index: false, zh: '实验室联系人电话' })
  lab_phone: string;
  @prop({ required: false, index: false, zh: '电子邮箱' })
  lab_email: string;
  @prop({ required: false, index: false, zh: '申报单位', props: unit })
  declare_unit: object;
  @prop({ required: false, index: false, zh: '平台负责人', props: leading_cadre })
  leading_cadre: object;
  @prop({ required: false, index: false, zh: '科研助理', props: assistant })
  assistant: object;
  @prop({ required: false, index: false, zh: '财务助理是否与科研助理同一人' })
  is_alike: boolean;
  @prop({ required: false, index: false, zh: '财务助理', props: finance })
  finance: object;
  @prop({ required: false, index: false, zh: '所属吉林省重点实验室' })
  ss_laboratory: string;
  @prop({ required: false, index: false, zh: '整合基础' })
  zh_basis: string;
  @prop({ required: false, index: false, zh: '是否公开', remark: '字典:info_show' })
  is_show: string;
  @prop({ required: false, index: false, zh: '地区' })
  region: string;
  @prop({ required: false, index: true, zh: '状态', default: '2' })
  status: string;
  @prop({ required: false, index: false, zh: '任职记录' })
  chief_logs: Array<any>;
}
