import { Rule, RuleType } from '@midwayjs/validate';
import { ApiProperty } from '@midwayjs/swagger';
import { FrameworkErrorEnum, SearchBase, ServiceError } from 'free-midway-component';
import get = require('lodash/get');
const dealVO = (cla, data) => {
  for (const key in cla) {
    const val = get(data, key);
    if (val || val === 0) cla[key] = val;
  }
};
export class FVO_user {
  constructor(data: object) {
    dealVO(this, data);
  }
  @ApiProperty({ description: '数据id' })
  _id: string = undefined;
  @ApiProperty({ description: '平台账户id' })
  'user_id': string = undefined;
  @ApiProperty({ description: '实验室id' })
  'lab_id': string = undefined;
}

export class QDTO_user extends SearchBase {
  constructor() {
    const like_prop = [];
    const props = ['user_id', 'lab_id'];
    const mapping = [];
    super({ like_prop, props, mapping });
  }
  @ApiProperty({ description: '平台账户id' })
  'user_id': string = undefined;
  @ApiProperty({ description: '实验室id' })
  'lab_id': string = undefined;
}

export class QVO_user extends FVO_user {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}

export class CDTO_user {
  @ApiProperty({ description: '平台账户id' })
  @Rule(RuleType['string']().required().error(new ServiceError('缺少平台账户id', FrameworkErrorEnum.NEED_BODY)))
  'user_id': string = undefined;
  @ApiProperty({ description: '实验室id' })
  @Rule(RuleType['string']().required().error(new ServiceError('缺少实验室id', FrameworkErrorEnum.NEED_BODY)))
  'lab_id': string = undefined;
}

export class CVO_user extends FVO_user {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}

export class UDTO_user extends CDTO_user {
  @ApiProperty({ description: '数据id' })
  @Rule(RuleType['string']().empty(''))
  _id: string = undefined;
}

export class UVAO_user extends FVO_user {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}
