import { IMiddleware, Inject } from '@midwayjs/core';
import { Middleware } from '@midwayjs/decorator';
import { NextFunction, Context } from '@midwayjs/koa';
import get = require('lodash/get');
import { JwtService } from '@midwayjs/jwt';
@Middleware()
export class SetUserMiddleware implements IMiddleware<Context, NextFunction> {
  @Inject()
  jwtService: JwtService;
  resolve() {
    return async (ctx: Context, next: NextFunction) => {
      const token = get(ctx, 'request.header.token');
      if (token) {
        const user = await this.jwtService.decode(token);
        ctx.user = user;
      }
      await next();
    };
  }

  static getName(): string {
    return 'setUser';
  }
}
