import { Provide } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import { BaseService } from 'free-midway-component';
import { Equipment } from '../../entity/lab/achievements/equipment.entity';
import round = require('lodash/round');
import divide = require('lodash/divide');
import get = require('lodash/get');
const assert = require('assert');
type modelType = ReturnModelType<typeof Equipment>;
@Provide()
export class EquipmentService extends BaseService<modelType> {
  @InjectEntityModel(Equipment)
  model: modelType;

  async statistics(lab_id) {
    assert(lab_id, '缺少实验室信息');
    const object = {
      total_number: 0, // 设备总台数
      instruments_total: 0, // 大型一起服务共享平台台数
      money: 0, // 设备总价值
      avg_research: 0, // 平均每台仪器服务工作总计时
      avg_service: 0, // 平均每台仪器服务工作总计时
      rate: 0, // 机时率:每台设备标准机时为K=1800小时/年；研究工作总机时（D）是指每台仪器每年本实验室研究人员使用的总时间；服务工作机时（E）是指每台仪器每年非本实验室工作人员使用的总时间；机时率（%）=（D+E）/K。
      area: 0, //科研场地面积
    };
    const K = 1800;
    const list = await this.model.find({ lab_id });
    object.total_number = list.length;
    object.instruments_total = list.filter(f => f.instruments_numb === '是').length;
    object.money = list.reduce((p, n) => parseFloat(get(n, 'equipment_money', '0')) + p, 0);
    const total_research = list.reduce((p, n) => parseFloat(get(n, 'research_hour', '0')) + p, 0);
    object.avg_research = round(divide(total_research, list.length) || 0, 2);
    const total_service = list.reduce((p, n) => parseFloat(get(n, 'services_hour', '0')) + p, 0);
    object.avg_service = round(divide(total_service, list.length) || 0, 2);
    object.rate = round(divide(total_research + total_service, K), 4) * 100;
    return object;
  }
}
