import { Provide } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { getModelForClass, ReturnModelType } from '@typegoose/typegoose';
import { BaseService } from 'free-midway-component';
import { Activitys } from '../entity/lab/activitys.entity';
import get = require('lodash/get');
import { Basic } from '../entity/lab/basic.entity';
import * as moment from 'moment';
type modelType = ReturnModelType<typeof Activitys>;
@Provide()
export class ActivitysService extends BaseService<modelType> {
  constructor(ctx) {
    super();
    if (!this.ctx && ctx) {
      this.ctx = ctx;
      if (!this.basicModel) this.basicModel = getModelForClass(Basic);
      if (!this.model) this.model = getModelForClass(Activitys);
    }
  }
  @InjectEntityModel(Activitys)
  model: modelType;

  @InjectEntityModel(Basic)
  basicModel: ReturnModelType<typeof Basic>;

  /**
   * 返回当前时间段的id
   */
  async addActTime() {
    const actTime = await this.isInAct();
    if (typeof actTime === 'object') {
      return get(actTime, '_id');
    }
  }

  /**
   * 查询当前时间是否在可以修改的时间段设置中
   */
  async isInAct(): Promise<boolean | object> {
    const role_type = get(this.ctx.user, 'role_type');
    if (role_type === '0' || role_type === '1') return true;
    if (!this.ctx.user) return false;
    const { lab_id } = this.ctx.user;
    // 根据实验室id找到实验室信息,获取实验室的状态;再在活动时间中看,该实验室状态的实验室是否在允许填写的时间内
    if (!lab_id) return false;
    const lab = await this.basicModel.findById(lab_id);
    if (!lab) return false;
    const { status = '0' } = lab;
    let type: string;
    if (status === '1') {
      // 筹建中实验室
      type = '-1';
    } else if (status === '2') {
      // 正常运营实验室
      type = '2';
    } else {
      // 其他类型实验室
      type = '1';
    }
    const query = { is_use: '0', type };
    const list = await this.model.find(query).lean();
    // 是否在可以修改时间内
    let result = true;
    for (const d of list) {
      const { start_time, end_time } = d;
      const res = moment().isBetween(start_time, end_time, null, '[]');
      if (res) {
        result = !res;
        break;
      }
    }
    return result;
  }
}
