import { Provide } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import { BaseService } from 'free-midway-component';
import { Region } from '../entity/lab/region.entity';
type modelType = ReturnModelType<typeof Region>;
@Provide()
export class RegionService extends BaseService<modelType> {
  @InjectEntityModel(Region)
  model: modelType;

  async newQuery(code): Promise<Array<any>> {
    let filter = this.filterRegex(code);
    if (!filter) filter = code ? { code } : {};
    let data = await this.getData(filter);
    if (data.length > 0) {
      data = await this.getChildren(data);
    }
    return data;
  }

  // 行政区划正则表达式
  filterRegex(code): object {
    const filter: any = {};
    if (!code) {
      filter.code = { $regex: /0000/ };
    } else {
      const prefix = code.substr(0, 2);
      const mid = code.substr(2, 2);
      const last = code.substr(4, 2);
      // 最后两位不是00,说明已经到区县级别,不需要再找了
      if (last !== '00') return null;
      else if (mid === '00') filter.code = { $regex: `${prefix}\\d{2}(?<!00)00` };
      else filter.code = { $regex: `${prefix}${mid}\\d{2}(?<!00)` };
    }
    return filter;
  }
  // 获取子地区
  async getChildren(data): Promise<Array<any>> {
    for (const d of data) {
      const filter = this.filterRegex(d.code);
      if (!filter) continue;
      const list = await this.getData(filter);
      if (list.length > 0) d.children = list;
      if (d.children) d.children = await this.getChildren(d.children);
    }
    return data;
  }
  // 执行查询
  async getData(filter): Promise<Array<any>> {
    let data = await this.model.find(filter);
    if (data.length > 0) data = JSON.parse(JSON.stringify(data));
    return data;
  }
}
